@@ -14,24 +14,24 @@ def build_config() -> dict[str, str]:
     """
     return dict(
         # Python settings
-        python_version="3.12",
-        python_install_dir=r"C:/M/msys64/clangarm64/lib/python3.12/site-packages/",
+        python_version="3.13",
+        python_install_dir=r"C:/M/msys64/clangarm64/lib/python3.13/site-packages/",
         python_path=r"C:/M/msys64/clangarm64/bin/python.exe",
 
         # Package versions
         contourpy_version="1.3.3",
-        meson_version="1.8.2",
+        meson_version="1.10.0",
         mesonpy_version="0.18.0",
-        pybind11_version="2.13.6",
+        pybind11_version="3.0.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"C:/W/B/src/python-build-CLANGARM64/.mesonpy-79ynklbd/lib/contourpy/util",
+        build_dir=r"C:/W/B/src/python-build-CLANGARM64/.mesonpy-jr55fk2n/lib/contourpy/util",
         source_dir=r"C:/W/B/src/python-build-CLANGARM64/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/W/B/src/python-build-CLANGARM64/.mesonpy-79ynklbd/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/W/B/src/python-build-CLANGARM64/.mesonpy-jr55fk2n/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="clang",
-        compiler_version="20.1.8",
+        compiler_version="21.1.8",
         linker_id="ld.lld",
         compile_command="clang++",
 
